============
Installation
============

.. contents::
   :local:

You can install hop-client either via pip, conda, or from source.

To install with pip:

.. code:: bash

   pip install -U hop-client


To install with conda:

.. code:: bash

    conda install -c conda-forge hop-client

To install from source:

.. code:: bash

    tar -xzf hop-client-x.y.z.tar.gz
    cd hop-client-x.y.z
    python setup.py install
